<?php

namespace Drupal\foldershare\Entity\FolderShareTraits;

/**
 * Get/set FolderShare entity enable content type field.
 *
 * This trait includes get and set methods for FolderShare entity
 * enable content type field.
 *
 * <B>Internal trait</B>
 * This trait is internal to the FolderShare module and used to define
 * features of the FolderShare entity class.
 *
 * @ingroup foldershare
 */
trait GetSetEnabledContentTypeTrait {

  /*---------------------------------------------------------------------
   *
   * Enabled content type field.
   *
   *---------------------------------------------------------------------*/
  /**
   * {@inheritdoc}
   */
  public function isEnabledContentType() {
    $value = $this->get('enabledcontenttype')->value;

    // An empty field is also FALSE.
    if (empty($value) === TRUE || $value === FALSE) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * Sets the enable content type flag.
   *
   * <B>This method is internal and strictly for use by the FolderShare
   * module itself.</B>
   *
   * The caller must call save() for the change to take effect.
   *
   * <B>Process locks</B>
   * This method does not lock access. The caller should lock around changes
   * to the entity.
   *
   * @param bool $state
   *   The new flag state.
   *
   * @return \Drupal\foldershare\FolderShareInterface
   *   Returns this item.
   *
   * @throws \Drupal\Core\TypedData\Exception\ReadOnlyException
   * @see ::isEnabledContentType()
   */
  public function setEnabledContentType(bool $state) {
    $this->enabledcontenttype->setValue($state);
    return $this;
  }

}
