<?php

namespace Drupal\foldershare\EventSubscriber;

use Drupal\foldershare\Entity\FolderShare;
use Drupal\foldershare\Event\UsersFolderCreateEvent;
use Drupal\foldershare\ManageFileSystem;
use Drupal\foldershare\Settings;
use Drupal\foldershare\Utilities\UserUtilities;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This class creates the default folders for each user.
 * When installing the foldershare module or setting up the foldershare settings,
 * this event is called
 *
 * Class UsersFolderCreateSubscriber.
 *
 * @package Drupal\foldershare\EventSubscriber
 */
class UsersFolderCreateSubscriber implements EventSubscriberInterface {

  /**
   * Database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * Date formatter.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      // Static class constant => method on this class.
      UsersFolderCreateEvent::EVENT_NAME => 'createUsersFolder',
    ];
  }

  /**
   * Subscribe to the user login event dispatched.
   *
   * @param UsersFolderCreateEvent $event
   *
   * @return void
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function createUsersFolder() {
    $result = &UserUtilities::getAllAccountNames();
    $homeFolderName = ManageFileSystem::FILE_DIRECTORY . '/' . Settings::getHomeFolderName();
    foreach ($result as $id => $name) {
      if ($id > 0) {
        $jobDirectory = $name . '/' . Settings::getJobFolderName();
        if (!ManageFileSystem::fileExists($jobDirectory)) {
          FolderShare::createDefaultFolder(Settings::getJobFolderName(), $id, Settings::getFileScheme(),
            $homeFolderName . '/' . $name);
        }
      }
    }
  }
}
