<?php

namespace Drupal\foldershare\ParamConverter;

use Drupal\Core\ParamConverter\ParamConverterInterface;
use Drupal\foldershare\Constants;
use Symfony\Component\Routing\Route;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * A parameter converter class to allow loading of foldershare entities.
 */
class FolderShareParamConverter implements ParamConverterInterface {

  /**
   * Entity type manager which performs the upcasting in the end.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EntityConverter.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritDoc}
   */
  public function convert($value, $definition, $name, array $defaults) {
    $entity = $this->entityTypeManager->getStorage($definition['type'])
      ->loadByProperties(['uuid' => $value]);
    if (count($entity) > 0) {
      return array_pop($entity);
    }
    return NULL;
  }

  /**
   * {@inheritDoc}
   */
  public function applies($definition, $name, Route $route) {
    if (!empty($definition['type']) && $definition['type'] === Constants::MODULE) {
      return TRUE;
    }
    return FALSE;
  }

}
