<?php

namespace Drupal\foldershare\Utilities;

/**
 * Defines utility functions for encoding and decoding the base64.
 *
 * The functions in this class help to create based64 string without including the slash(/).
 *
 * @ingroup foldershare
 */
final class Base64Utilities {

  /*---------------------------------------------------------------------
   *
   * Utilities.
   *
   *---------------------------------------------------------------------*/
  /**
   * Encode a string using base64url encoding.
   *
   * @param string $data
   *   The string to encode.
   *
   * @return string
   *   The base64url-encoded string.
   */
  public static function base64urlEncode($data) {
    $base64 = base64_encode($data);
    $base64url = strtr($base64, '+/', '-_');
    $base64url = rtrim($base64url, '=');
    return $base64url;
  }

  /**
   * Decode a base64url-encoded string.
   *
   * @param string $data
   *   The base64url-encoded string.
   *
   * @return string|bool
   *   The decoded string, or false if decoding fails.
   */
  public static function base64urlDecode($data) {
    $base64 = strtr($data, '-_', '+/');
    $paddedLength = strlen($base64) % 4;
    if ($paddedLength) {
      $base64 .= str_repeat('=', 4 - $paddedLength);
    }
    return base64_decode($base64);
  }

}
